<?php
// Database configuration
$host = 'localhost';
$username = 'your_username';
$password = 'your_password';
$database = 'your_database_name';

// Create a connection to the database
$conn = new mysqli($host, $username, $password, $database);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Set the file name for the export
$backup_file = 'backup-' . date('Y-m-d_H-i-s') . '.sql';

// Open file for writing
$handle = fopen($backup_file, 'w+');
if (!$handle) {
    die('Cannot open file: ' . $backup_file);
}

// Add header to the file
fwrite($handle, "-- Database Backup\n");
fwrite($handle, "-- Host: $host\n");
fwrite($handle, "-- Database: $database\n");
fwrite($handle, "-- Generation Time: " . date('Y-m-d H:i:s') . "\n\n");

// Get the list of all tables
$tables_result = $conn->query("SHOW TABLES");
if ($tables_result === false) {
    die("Error retrieving tables: " . $conn->error);
}

while ($table_row = $tables_result->fetch_row()) {
    $table = $table_row[0];

    // Add table structure
    $structure_result = $conn->query("SHOW CREATE TABLE `$table`");
    if ($structure_result === false) {
        die("Error retrieving table structure for $table: " . $conn->error);
    }

    $structure_row = $structure_result->fetch_row();
    fwrite($handle, "-- Structure for table `$table`\n");
    fwrite($handle, $structure_row[1] . ";\n\n");

    // Get the total number of rows in the table
    $count_result = $conn->query("SELECT COUNT(*) FROM `$table`");
    if ($count_result === false) {
        die("Error counting rows in $table: " . $conn->error);
    }
    $total_rows = $count_result->fetch_row()[0];

    // Set the chunk size for pagination (e.g., 1000 rows per batch)
    $chunk_size = 1000;

    // Export data in chunks
    for ($offset = 0; $offset < $total_rows; $offset += $chunk_size) {
        $data_result = $conn->query("SELECT * FROM `$table` LIMIT $offset, $chunk_size");

        if ($data_result === false) {
            die("Error retrieving data for $table: " . $conn->error);
        }

        if ($data_result->num_rows > 0) {
            fwrite($handle, "-- Data for table `$table`\n");
            while ($row = $data_result->fetch_assoc()) {
                $values = array_map([$conn, 'real_escape_string'], array_values($row));
                $values = "'" . implode("','", $values) . "'";
                $sql = "INSERT INTO `$table` (`" . implode('`,`', array_keys($row)) . "`) VALUES ($values);\n";
                fwrite($handle, $sql);
            }
            fwrite($handle, "\n");
        }
    }
}

// Close the file handle
fclose($handle);

// Close the database connection
$conn->close();

echo "Database export successful. Backup file created: $backup_file";
?>
